
Example of 'todo' usage
=======================

see `todo extension page`_ for more documentation.

Bla bla some text.

.. todo::
    1) something really import to do in the next version

Bla bla some other text.

.. todo::
    2) Is this really that important in the end?

Bla bla some final remarks

Todo list
---------

.. todolist::

.. _`todo extension page`: http://www.sphinx-doc.org/en/stable/ext/todo.html
